==> igniteui-react-core-16.16.1.tgz: package/esm5/lib/RenderRequestedEventArgsDescriptionMetadata.js <==
/*
THIS INFRAGISTICS ULTIMATE SOFTWARE LICENSE  AGREEMENT ("AGREEMENT") LOCATED HERE:
https://www.infragistics.com/legal/license/igultimate-la
https://www.infragistics.com/legal/license/igultimate-eula
GOVERNS THE LICENSING, INSTALLATION AND USE OF INFRAGISTICS SOFTWARE. BY DOWNLOADING AND/OR INSTALLING AND USING INFRAGISTICS SOFTWARE:  you are indicating that you have read and understand this Agreement, and agree to be legally bound by it on behalf of the yourself and your company.
*/
import { __extends } from "tslib";
import { Base, String_$type, markType } from "./type";
import { Dictionary$2 } from "./Dictionary$2";
import { RenderRequestedEventArgsDescription } from "./RenderRequestedEventArgsDescription";
/**
 * @hidden
 */
var RenderRequestedEventArgsDescriptionMetadata = /** @class */ /*@__PURE__*/ (function (_super) {
    __extends(RenderRequestedEventArgsDescriptionMetadata, _super);
    function RenderRequestedEventArgsDescriptionMetadata() {
        return _super !== null && _super.apply(this, arguments) || this;
    }
    RenderRequestedEventArgsDescriptionMetadata.b = function (a) {
        if (RenderRequestedEventArgsDescriptionMetadata.a == null) {
            RenderRequestedEventArgsDescriptionMetadata.a = new Dictionary$2(String_$type, String_$type, 0);
            RenderRequestedEventArgsDescriptionMetadata.c(RenderRequestedEventArgsDescriptionMetadata.a);
        }
        if (a.g(RenderRequestedEventArgsDescriptionMetadata.a)) {
            return;
        }
        a.s(RenderRequestedEventArgsDescriptionMetadata.a);
    };
    RenderRequestedEventArgsDescriptionMetadata.c = function (a) {
        a.item("Animate", "Boolean");
    };
    RenderRequestedEventArgsDescriptionMetadata.d = function (a) {
        RenderRequestedEventArgsDescriptionMetadata.b(a);
        a.u("RenderRequestedEventArgs", function () { return new RenderRequestedEventArgsDescription(); });
        a.t("RenderRequestedEventArgs", RenderRequestedEventArgsDescriptionMetadata.a);
    };
    RenderRequestedEventArgsDescriptionMetadata.$t = markType(RenderRequestedEventArgsDescriptionMetadata, 'RenderRequestedEventArgsDescriptionMetadata');
    RenderRequestedEventArgsDescriptionMetadata.a = null;
    return RenderRequestedEventArgsDescriptionMetadata;
}(Base));
export { RenderRequestedEventArgsDescriptionMetadata };

==> igniteui-react-core-18.1.2.tgz: package/esm5/lib/RenderRequestedEventArgsDescriptionMetadata.js <==
/*
THIS INFRAGISTICS ULTIMATE SOFTWARE LICENSE  AGREEMENT ("AGREEMENT") LOCATED HERE:
https://www.infragistics.com/legal/license/igultimate-la
https://www.infragistics.com/legal/license/igultimate-eula
GOVERNS THE LICENSING, INSTALLATION AND USE OF INFRAGISTICS SOFTWARE. BY DOWNLOADING AND/OR INSTALLING AND USING INFRAGISTICS SOFTWARE:  you are indicating that you have read and understand this Agreement, and agree to be legally bound by it on behalf of the yourself and your company.
*/
import { __extends } from "tslib";
import { Base, String_$type, markType } from "./type";
import { Dictionary$2 } from "./Dictionary$2";
import { RenderRequestedEventArgsDescription } from "./RenderRequestedEventArgsDescription";
/**
 * @hidden
 */
var RenderRequestedEventArgsDescriptionMetadata = /** @class */ /*@__PURE__*/ (function (_super) {
    __extends(RenderRequestedEventArgsDescriptionMetadata, _super);
    function RenderRequestedEventArgsDescriptionMetadata() {
        return _super !== null && _super.apply(this, arguments) || this;
    }
    RenderRequestedEventArgsDescriptionMetadata.b = function (a) {
        if (RenderRequestedEventArgsDescriptionMetadata.a == null) {
            RenderRequestedEventArgsDescriptionMetadata.a = new Dictionary$2(String_$type, String_$type, 0);
            RenderRequestedEventArgsDescriptionMetadata.c(RenderRequestedEventArgsDescriptionMetadata.a);
        }
        if (a.j(RenderRequestedEventArgsDescriptionMetadata.a)) {
            return;
        }
        a.y(RenderRequestedEventArgsDescriptionMetadata.a);
    };
    RenderRequestedEventArgsDescriptionMetadata.c = function (a) {
        a.item("Animate", "Boolean");
    };
    RenderRequestedEventArgsDescriptionMetadata.d = function (a) {
        RenderRequestedEventArgsDescriptionMetadata.b(a);
        a.aa("RenderRequestedEventArgs", function () { return new RenderRequestedEventArgsDescription(); });
        a.z("RenderRequestedEventArgs", RenderRequestedEventArgsDescriptionMetadata.a);
    };
    RenderRequestedEventArgsDescriptionMetadata.$t = markType(RenderRequestedEventArgsDescriptionMetadata, 'RenderRequestedEventArgsDescriptionMetadata');
    RenderRequestedEventArgsDescriptionMetadata.a = null;
    return RenderRequestedEventArgsDescriptionMetadata;
}(Base));
export { RenderRequestedEventArgsDescriptionMetadata };
